==> mule-artifact-ast-1.1.0-20220125-sources.jar: org/mule/runtime/ast/internal/validation/DefaultValidationResultItem.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.internal.validation;

import org.mule.runtime.ast.api.ComponentAst;
import org.mule.runtime.ast.api.ComponentParameterAst;
import org.mule.runtime.ast.api.validation.Validation;
import org.mule.runtime.ast.api.validation.ValidationResultItem;

import java.util.List;
import java.util.Map;

/**
 * Implementation of {@link ValidationResultItem} that keeps internal state for the result item.
 *
 * @since 1.0
 */
public class DefaultValidationResultItem implements ValidationResultItem {

  private final List<ComponentAst> components;
  private final List<ComponentParameterAst> parameters;
  private final Validation validation;
  private final String message;
  private final Map<String, String> additionalData;

  public DefaultValidationResultItem(List<ComponentAst> components, List<ComponentParameterAst> parameters, Validation validation,
                                     String message, Map<String, String> additionalData) {
    this.components = components;
    this.parameters = parameters;
    this.validation = validation;
    this.message = message;
    this.additionalData = additionalData;
  }

  @Override
  public List<ComponentAst> getComponents() {
    return components;
  }

  @Override
  public List<ComponentParameterAst> getParameters() {
    return parameters;
  }

  @Override
  public Validation getValidation() {
    return validation;
  }

  @Override
  public String getMessage() {
    return message;
  }

  @Override
  public Map<String, String> getAdditionalData() {
    return additionalData;
  }
}

==> mule-artifact-ast-1.5.9-sources.jar: org/mule/runtime/ast/internal/validation/DefaultValidationResultItem.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.internal.validation;

import org.mule.runtime.ast.api.ComponentAst;
import org.mule.runtime.ast.api.ComponentParameterAst;
import org.mule.runtime.ast.api.validation.Validation;
import org.mule.runtime.ast.api.validation.ValidationResultItem;

import java.util.List;
import java.util.Map;

/**
 * Implementation of {@link ValidationResultItem} that keeps internal state for the result item.
 *
 * @since 1.0
 */
public class DefaultValidationResultItem implements ValidationResultItem {

  private final List<ComponentAst> components;
  private final List<ComponentParameterAst> parameters;
  private final Validation validation;
  private final String message;
  private final Map<String, String> additionalData;
  private final boolean causedByDynamicArtifact;

  public DefaultValidationResultItem(List<ComponentAst> components, List<ComponentParameterAst> parameters, Validation validation,
                                     String message, Map<String, String> additionalData, boolean causedByDynamicArtifact) {
    this.components = components;
    this.parameters = parameters;
    this.validation = validation;
    this.message = message;
    this.additionalData = additionalData;
    this.causedByDynamicArtifact = causedByDynamicArtifact;
  }

  @Override
  public List<ComponentAst> getComponents() {
    return components;
  }

  @Override
  public List<ComponentParameterAst> getParameters() {
    return parameters;
  }

  @Override
  public Validation getValidation() {
    return validation;
  }

  @Override
  public String getMessage() {
    return message;
  }

  @Override
  public Map<String, String> getAdditionalData() {
    return additionalData;
  }

  @Override
  public boolean causedByDynamicArtifact() {
    return causedByDynamicArtifact;
  }
}
